# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v2.0.5.5160
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from prowlarr.models.host_statistics import HostStatistics
from prowlarr.models.indexer_statistics import IndexerStatistics
from prowlarr.models.user_agent_statistics import UserAgentStatistics
from typing import Optional, Set
from typing_extensions import Self

class IndexerStatsResource(BaseModel):
    """
    IndexerStatsResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    indexers: Optional[List[IndexerStatistics]] = None
    user_agents: Optional[List[UserAgentStatistics]] = Field(default=None, alias="userAgents")
    hosts: Optional[List[HostStatistics]] = None
    __properties: ClassVar[List[str]] = ["id", "indexers", "userAgents", "hosts"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IndexerStatsResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in indexers (list)
        _items = []
        if self.indexers:
            for _item_indexers in self.indexers:
                if _item_indexers:
                    _items.append(_item_indexers.to_dict())
            _dict['indexers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in user_agents (list)
        _items = []
        if self.user_agents:
            for _item_user_agents in self.user_agents:
                if _item_user_agents:
                    _items.append(_item_user_agents.to_dict())
            _dict['userAgents'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in hosts (list)
        _items = []
        if self.hosts:
            for _item_hosts in self.hosts:
                if _item_hosts:
                    _items.append(_item_hosts.to_dict())
            _dict['hosts'] = _items
        # set to None if indexers (nullable) is None
        # and model_fields_set contains the field
        if self.indexers is None and "indexers" in self.model_fields_set:
            _dict['indexers'] = None

        # set to None if user_agents (nullable) is None
        # and model_fields_set contains the field
        if self.user_agents is None and "user_agents" in self.model_fields_set:
            _dict['userAgents'] = None

        # set to None if hosts (nullable) is None
        # and model_fields_set contains the field
        if self.hosts is None and "hosts" in self.model_fields_set:
            _dict['hosts'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IndexerStatsResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "indexers": [IndexerStatistics.from_dict(_item) for _item in obj["indexers"]] if obj.get("indexers") is not None else None,
            "userAgents": [UserAgentStatistics.from_dict(_item) for _item in obj["userAgents"]] if obj.get("userAgents") is not None else None,
            "hosts": [HostStatistics.from_dict(_item) for _item in obj["hosts"]] if obj.get("hosts") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v2.0.5.5160
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.1" # x-release-please-version

# Define package exports
__all__ = [
    "ApiInfoApi",
    "AppProfileApi",
    "ApplicationApi",
    "AuthenticationApi",
    "BackupApi",
    "CommandApi",
    "CustomFilterApi",
    "DevelopmentConfigApi",
    "DownloadClientApi",
    "DownloadClientConfigApi",
    "FileSystemApi",
    "HealthApi",
    "HistoryApi",
    "HostConfigApi",
    "IndexerApi",
    "IndexerDefaultCategoriesApi",
    "IndexerProxyApi",
    "IndexerStatsApi",
    "IndexerStatusApi",
    "LocalizationApi",
    "LogApi",
    "LogFileApi",
    "NewznabApi",
    "NotificationApi",
    "PingApi",
    "SearchApi",
    "StaticResourceApi",
    "SystemApi",
    "TagApi",
    "TagDetailsApi",
    "TaskApi",
    "UiConfigApi",
    "UpdateApi",
    "UpdateLogFileApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiInfoResource",
    "AppProfileResource",
    "ApplicationBulkResource",
    "ApplicationResource",
    "ApplicationSyncLevel",
    "ApplyTags",
    "AuthenticationRequiredType",
    "AuthenticationType",
    "BackupResource",
    "BackupType",
    "BookSearchParam",
    "CertificateValidationType",
    "Command",
    "CommandPriority",
    "CommandResource",
    "CommandStatus",
    "CommandTrigger",
    "ContractField",
    "CustomFilterResource",
    "DatabaseType",
    "DevelopmentConfigResource",
    "DownloadClientBulkResource",
    "DownloadClientCategory",
    "DownloadClientConfigResource",
    "DownloadClientResource",
    "DownloadProtocol",
    "HealthCheckResult",
    "HealthResource",
    "HistoryEventType",
    "HistoryResource",
    "HistoryResourcePagingResource",
    "HostConfigResource",
    "HostStatistics",
    "IndexerBulkResource",
    "IndexerCapabilityResource",
    "IndexerCategory",
    "IndexerPrivacy",
    "IndexerProxyResource",
    "IndexerResource",
    "IndexerStatistics",
    "IndexerStatsResource",
    "IndexerStatusResource",
    "LocalizationOption",
    "LogFileResource",
    "LogResource",
    "LogResourcePagingResource",
    "MovieSearchParam",
    "MusicSearchParam",
    "NotificationResource",
    "PingResource",
    "PrivacyLevel",
    "ProviderMessage",
    "ProviderMessageType",
    "ProxyType",
    "ReleaseResource",
    "RuntimeMode",
    "SearchParam",
    "SelectOption",
    "SortDirection",
    "SystemResource",
    "TagDetailsResource",
    "TagResource",
    "TaskResource",
    "TvSearchParam",
    "UiConfigResource",
    "UpdateChanges",
    "UpdateMechanism",
    "UpdateResource",
    "UserAgentStatistics",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from prowlarr.api.api_info_api import ApiInfoApi as ApiInfoApi
    from prowlarr.api.app_profile_api import AppProfileApi as AppProfileApi
    from prowlarr.api.application_api import ApplicationApi as ApplicationApi
    from prowlarr.api.authentication_api import AuthenticationApi as AuthenticationApi
    from prowlarr.api.backup_api import BackupApi as BackupApi
    from prowlarr.api.command_api import CommandApi as CommandApi
    from prowlarr.api.custom_filter_api import CustomFilterApi as CustomFilterApi
    from prowlarr.api.development_config_api import DevelopmentConfigApi as DevelopmentConfigApi
    from prowlarr.api.download_client_api import DownloadClientApi as DownloadClientApi
    from prowlarr.api.download_client_config_api import DownloadClientConfigApi as DownloadClientConfigApi
    from prowlarr.api.file_system_api import FileSystemApi as FileSystemApi
    from prowlarr.api.health_api import HealthApi as HealthApi
    from prowlarr.api.history_api import HistoryApi as HistoryApi
    from prowlarr.api.host_config_api import HostConfigApi as HostConfigApi
    from prowlarr.api.indexer_api import IndexerApi as IndexerApi
    from prowlarr.api.indexer_default_categories_api import IndexerDefaultCategoriesApi as IndexerDefaultCategoriesApi
    from prowlarr.api.indexer_proxy_api import IndexerProxyApi as IndexerProxyApi
    from prowlarr.api.indexer_stats_api import IndexerStatsApi as IndexerStatsApi
    from prowlarr.api.indexer_status_api import IndexerStatusApi as IndexerStatusApi
    from prowlarr.api.localization_api import LocalizationApi as LocalizationApi
    from prowlarr.api.log_api import LogApi as LogApi
    from prowlarr.api.log_file_api import LogFileApi as LogFileApi
    from prowlarr.api.newznab_api import NewznabApi as NewznabApi
    from prowlarr.api.notification_api import NotificationApi as NotificationApi
    from prowlarr.api.ping_api import PingApi as PingApi
    from prowlarr.api.search_api import SearchApi as SearchApi
    from prowlarr.api.static_resource_api import StaticResourceApi as StaticResourceApi
    from prowlarr.api.system_api import SystemApi as SystemApi
    from prowlarr.api.tag_api import TagApi as TagApi
    from prowlarr.api.tag_details_api import TagDetailsApi as TagDetailsApi
    from prowlarr.api.task_api import TaskApi as TaskApi
    from prowlarr.api.ui_config_api import UiConfigApi as UiConfigApi
    from prowlarr.api.update_api import UpdateApi as UpdateApi
    from prowlarr.api.update_log_file_api import UpdateLogFileApi as UpdateLogFileApi
    
    # import ApiClient
    from prowlarr.api_response import ApiResponse as ApiResponse
    from prowlarr.api_client import ApiClient as ApiClient
    from prowlarr.configuration import Configuration as Configuration
    from prowlarr.exceptions import OpenApiException as OpenApiException
    from prowlarr.exceptions import ApiTypeError as ApiTypeError
    from prowlarr.exceptions import ApiValueError as ApiValueError
    from prowlarr.exceptions import ApiKeyError as ApiKeyError
    from prowlarr.exceptions import ApiAttributeError as ApiAttributeError
    from prowlarr.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from prowlarr.models.api_info_resource import ApiInfoResource as ApiInfoResource
    from prowlarr.models.app_profile_resource import AppProfileResource as AppProfileResource
    from prowlarr.models.application_bulk_resource import ApplicationBulkResource as ApplicationBulkResource
    from prowlarr.models.application_resource import ApplicationResource as ApplicationResource
    from prowlarr.models.application_sync_level import ApplicationSyncLevel as ApplicationSyncLevel
    from prowlarr.models.apply_tags import ApplyTags as ApplyTags
    from prowlarr.models.authentication_required_type import AuthenticationRequiredType as AuthenticationRequiredType
    from prowlarr.models.authentication_type import AuthenticationType as AuthenticationType
    from prowlarr.models.backup_resource import BackupResource as BackupResource
    from prowlarr.models.backup_type import BackupType as BackupType
    from prowlarr.models.book_search_param import BookSearchParam as BookSearchParam
    from prowlarr.models.certificate_validation_type import CertificateValidationType as CertificateValidationType
    from prowlarr.models.command import Command as Command
    from prowlarr.models.command_priority import CommandPriority as CommandPriority
    from prowlarr.models.command_resource import CommandResource as CommandResource
    from prowlarr.models.command_status import CommandStatus as CommandStatus
    from prowlarr.models.command_trigger import CommandTrigger as CommandTrigger
    from prowlarr.models.contract_field import ContractField as ContractField
    from prowlarr.models.custom_filter_resource import CustomFilterResource as CustomFilterResource
    from prowlarr.models.database_type import DatabaseType as DatabaseType
    from prowlarr.models.development_config_resource import DevelopmentConfigResource as DevelopmentConfigResource
    from prowlarr.models.download_client_bulk_resource import DownloadClientBulkResource as DownloadClientBulkResource
    from prowlarr.models.download_client_category import DownloadClientCategory as DownloadClientCategory
    from prowlarr.models.download_client_config_resource import DownloadClientConfigResource as DownloadClientConfigResource
    from prowlarr.models.download_client_resource import DownloadClientResource as DownloadClientResource
    from prowlarr.models.download_protocol import DownloadProtocol as DownloadProtocol
    from prowlarr.models.health_check_result import HealthCheckResult as HealthCheckResult
    from prowlarr.models.health_resource import HealthResource as HealthResource
    from prowlarr.models.history_event_type import HistoryEventType as HistoryEventType
    from prowlarr.models.history_resource import HistoryResource as HistoryResource
    from prowlarr.models.history_resource_paging_resource import HistoryResourcePagingResource as HistoryResourcePagingResource
    from prowlarr.models.host_config_resource import HostConfigResource as HostConfigResource
    from prowlarr.models.host_statistics import HostStatistics as HostStatistics
    from prowlarr.models.indexer_bulk_resource import IndexerBulkResource as IndexerBulkResource
    from prowlarr.models.indexer_capability_resource import IndexerCapabilityResource as IndexerCapabilityResource
    from prowlarr.models.indexer_category import IndexerCategory as IndexerCategory
    from prowlarr.models.indexer_privacy import IndexerPrivacy as IndexerPrivacy
    from prowlarr.models.indexer_proxy_resource import IndexerProxyResource as IndexerProxyResource
    from prowlarr.models.indexer_resource import IndexerResource as IndexerResource
    from prowlarr.models.indexer_statistics import IndexerStatistics as IndexerStatistics
    from prowlarr.models.indexer_stats_resource import IndexerStatsResource as IndexerStatsResource
    from prowlarr.models.indexer_status_resource import IndexerStatusResource as IndexerStatusResource
    from prowlarr.models.localization_option import LocalizationOption as LocalizationOption
    from prowlarr.models.log_file_resource import LogFileResource as LogFileResource
    from prowlarr.models.log_resource import LogResource as LogResource
    from prowlarr.models.log_resource_paging_resource import LogResourcePagingResource as LogResourcePagingResource
    from prowlarr.models.movie_search_param import MovieSearchParam as MovieSearchParam
    from prowlarr.models.music_search_param import MusicSearchParam as MusicSearchParam
    from prowlarr.models.notification_resource import NotificationResource as NotificationResource
    from prowlarr.models.ping_resource import PingResource as PingResource
    from prowlarr.models.privacy_level import PrivacyLevel as PrivacyLevel
    from prowlarr.models.provider_message import ProviderMessage as ProviderMessage
    from prowlarr.models.provider_message_type import ProviderMessageType as ProviderMessageType
    from prowlarr.models.proxy_type import ProxyType as ProxyType
    from prowlarr.models.release_resource import ReleaseResource as ReleaseResource
    from prowlarr.models.runtime_mode import RuntimeMode as RuntimeMode
    from prowlarr.models.search_param import SearchParam as SearchParam
    from prowlarr.models.select_option import SelectOption as SelectOption
    from prowlarr.models.sort_direction import SortDirection as SortDirection
    from prowlarr.models.system_resource import SystemResource as SystemResource
    from prowlarr.models.tag_details_resource import TagDetailsResource as TagDetailsResource
    from prowlarr.models.tag_resource import TagResource as TagResource
    from prowlarr.models.task_resource import TaskResource as TaskResource
    from prowlarr.models.tv_search_param import TvSearchParam as TvSearchParam
    from prowlarr.models.ui_config_resource import UiConfigResource as UiConfigResource
    from prowlarr.models.update_changes import UpdateChanges as UpdateChanges
    from prowlarr.models.update_mechanism import UpdateMechanism as UpdateMechanism
    from prowlarr.models.update_resource import UpdateResource as UpdateResource
    from prowlarr.models.user_agent_statistics import UserAgentStatistics as UserAgentStatistics
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from prowlarr.api.api_info_api import ApiInfoApi as ApiInfoApi
from prowlarr.api.app_profile_api import AppProfileApi as AppProfileApi
from prowlarr.api.application_api import ApplicationApi as ApplicationApi
from prowlarr.api.authentication_api import AuthenticationApi as AuthenticationApi
from prowlarr.api.backup_api import BackupApi as BackupApi
from prowlarr.api.command_api import CommandApi as CommandApi
from prowlarr.api.custom_filter_api import CustomFilterApi as CustomFilterApi
from prowlarr.api.development_config_api import DevelopmentConfigApi as DevelopmentConfigApi
from prowlarr.api.download_client_api import DownloadClientApi as DownloadClientApi
from prowlarr.api.download_client_config_api import DownloadClientConfigApi as DownloadClientConfigApi
from prowlarr.api.file_system_api import FileSystemApi as FileSystemApi
from prowlarr.api.health_api import HealthApi as HealthApi
from prowlarr.api.history_api import HistoryApi as HistoryApi
from prowlarr.api.host_config_api import HostConfigApi as HostConfigApi
from prowlarr.api.indexer_api import IndexerApi as IndexerApi
from prowlarr.api.indexer_default_categories_api import IndexerDefaultCategoriesApi as IndexerDefaultCategoriesApi
from prowlarr.api.indexer_proxy_api import IndexerProxyApi as IndexerProxyApi
from prowlarr.api.indexer_stats_api import IndexerStatsApi as IndexerStatsApi
from prowlarr.api.indexer_status_api import IndexerStatusApi as IndexerStatusApi
from prowlarr.api.localization_api import LocalizationApi as LocalizationApi
from prowlarr.api.log_api import LogApi as LogApi
from prowlarr.api.log_file_api import LogFileApi as LogFileApi
from prowlarr.api.newznab_api import NewznabApi as NewznabApi
from prowlarr.api.notification_api import NotificationApi as NotificationApi
from prowlarr.api.ping_api import PingApi as PingApi
from prowlarr.api.search_api import SearchApi as SearchApi
from prowlarr.api.static_resource_api import StaticResourceApi as StaticResourceApi
from prowlarr.api.system_api import SystemApi as SystemApi
from prowlarr.api.tag_api import TagApi as TagApi
from prowlarr.api.tag_details_api import TagDetailsApi as TagDetailsApi
from prowlarr.api.task_api import TaskApi as TaskApi
from prowlarr.api.ui_config_api import UiConfigApi as UiConfigApi
from prowlarr.api.update_api import UpdateApi as UpdateApi
from prowlarr.api.update_log_file_api import UpdateLogFileApi as UpdateLogFileApi

# import ApiClient
from prowlarr.api_response import ApiResponse as ApiResponse
from prowlarr.api_client import ApiClient as ApiClient
from prowlarr.configuration import Configuration as Configuration
from prowlarr.exceptions import OpenApiException as OpenApiException
from prowlarr.exceptions import ApiTypeError as ApiTypeError
from prowlarr.exceptions import ApiValueError as ApiValueError
from prowlarr.exceptions import ApiKeyError as ApiKeyError
from prowlarr.exceptions import ApiAttributeError as ApiAttributeError
from prowlarr.exceptions import ApiException as ApiException

# import models into sdk package
from prowlarr.models.api_info_resource import ApiInfoResource as ApiInfoResource
from prowlarr.models.app_profile_resource import AppProfileResource as AppProfileResource
from prowlarr.models.application_bulk_resource import ApplicationBulkResource as ApplicationBulkResource
from prowlarr.models.application_resource import ApplicationResource as ApplicationResource
from prowlarr.models.application_sync_level import ApplicationSyncLevel as ApplicationSyncLevel
from prowlarr.models.apply_tags import ApplyTags as ApplyTags
from prowlarr.models.authentication_required_type import AuthenticationRequiredType as AuthenticationRequiredType
from prowlarr.models.authentication_type import AuthenticationType as AuthenticationType
from prowlarr.models.backup_resource import BackupResource as BackupResource
from prowlarr.models.backup_type import BackupType as BackupType
from prowlarr.models.book_search_param import BookSearchParam as BookSearchParam
from prowlarr.models.certificate_validation_type import CertificateValidationType as CertificateValidationType
from prowlarr.models.command import Command as Command
from prowlarr.models.command_priority import CommandPriority as CommandPriority
from prowlarr.models.command_resource import CommandResource as CommandResource
from prowlarr.models.command_status import CommandStatus as CommandStatus
from prowlarr.models.command_trigger import CommandTrigger as CommandTrigger
from prowlarr.models.contract_field import ContractField as ContractField
from prowlarr.models.custom_filter_resource import CustomFilterResource as CustomFilterResource
from prowlarr.models.database_type import DatabaseType as DatabaseType
from prowlarr.models.development_config_resource import DevelopmentConfigResource as DevelopmentConfigResource
from prowlarr.models.download_client_bulk_resource import DownloadClientBulkResource as DownloadClientBulkResource
from prowlarr.models.download_client_category import DownloadClientCategory as DownloadClientCategory
from prowlarr.models.download_client_config_resource import DownloadClientConfigResource as DownloadClientConfigResource
from prowlarr.models.download_client_resource import DownloadClientResource as DownloadClientResource
from prowlarr.models.download_protocol import DownloadProtocol as DownloadProtocol
from prowlarr.models.health_check_result import HealthCheckResult as HealthCheckResult
from prowlarr.models.health_resource import HealthResource as HealthResource
from prowlarr.models.history_event_type import HistoryEventType as HistoryEventType
from prowlarr.models.history_resource import HistoryResource as HistoryResource
from prowlarr.models.history_resource_paging_resource import HistoryResourcePagingResource as HistoryResourcePagingResource
from prowlarr.models.host_config_resource import HostConfigResource as HostConfigResource
from prowlarr.models.host_statistics import HostStatistics as HostStatistics
from prowlarr.models.indexer_bulk_resource import IndexerBulkResource as IndexerBulkResource
from prowlarr.models.indexer_capability_resource import IndexerCapabilityResource as IndexerCapabilityResource
from prowlarr.models.indexer_category import IndexerCategory as IndexerCategory
from prowlarr.models.indexer_privacy import IndexerPrivacy as IndexerPrivacy
from prowlarr.models.indexer_proxy_resource import IndexerProxyResource as IndexerProxyResource
from prowlarr.models.indexer_resource import IndexerResource as IndexerResource
from prowlarr.models.indexer_statistics import IndexerStatistics as IndexerStatistics
from prowlarr.models.indexer_stats_resource import IndexerStatsResource as IndexerStatsResource
from prowlarr.models.indexer_status_resource import IndexerStatusResource as IndexerStatusResource
from prowlarr.models.localization_option import LocalizationOption as LocalizationOption
from prowlarr.models.log_file_resource import LogFileResource as LogFileResource
from prowlarr.models.log_resource import LogResource as LogResource
from prowlarr.models.log_resource_paging_resource import LogResourcePagingResource as LogResourcePagingResource
from prowlarr.models.movie_search_param import MovieSearchParam as MovieSearchParam
from prowlarr.models.music_search_param import MusicSearchParam as MusicSearchParam
from prowlarr.models.notification_resource import NotificationResource as NotificationResource
from prowlarr.models.ping_resource import PingResource as PingResource
from prowlarr.models.privacy_level import PrivacyLevel as PrivacyLevel
from prowlarr.models.provider_message import ProviderMessage as ProviderMessage
from prowlarr.models.provider_message_type import ProviderMessageType as ProviderMessageType
from prowlarr.models.proxy_type import ProxyType as ProxyType
from prowlarr.models.release_resource import ReleaseResource as ReleaseResource
from prowlarr.models.runtime_mode import RuntimeMode as RuntimeMode
from prowlarr.models.search_param import SearchParam as SearchParam
from prowlarr.models.select_option import SelectOption as SelectOption
from prowlarr.models.sort_direction import SortDirection as SortDirection
from prowlarr.models.system_resource import SystemResource as SystemResource
from prowlarr.models.tag_details_resource import TagDetailsResource as TagDetailsResource
from prowlarr.models.tag_resource import TagResource as TagResource
from prowlarr.models.task_resource import TaskResource as TaskResource
from prowlarr.models.tv_search_param import TvSearchParam as TvSearchParam
from prowlarr.models.ui_config_resource import UiConfigResource as UiConfigResource
from prowlarr.models.update_changes import UpdateChanges as UpdateChanges
from prowlarr.models.update_mechanism import UpdateMechanism as UpdateMechanism
from prowlarr.models.update_resource import UpdateResource as UpdateResource
from prowlarr.models.user_agent_statistics import UserAgentStatistics as UserAgentStatistics

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v2.0.5.5160
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import StrictBool, StrictInt, StrictStr
from typing import List, Optional
from prowlarr.models.history_event_type import HistoryEventType
from prowlarr.models.history_resource import HistoryResource
from prowlarr.models.history_resource_paging_resource import HistoryResourcePagingResource
from prowlarr.models.sort_direction import SortDirection

from prowlarr.api_client import ApiClient, RequestSerialized
from prowlarr.api_response import ApiResponse
from prowlarr.rest import RESTResponseType


class HistoryApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_history(
        self,
        page: Optional[StrictInt] = None,
        page_size: Optional[StrictInt] = None,
        sort_key: Optional[StrictStr] = None,
        sort_direction: Optional[SortDirection] = None,
        event_type: Optional[List[StrictInt]] = None,
        successful: Optional[StrictBool] = None,
        download_id: Optional[StrictStr] = None,
        indexer_ids: Optional[List[StrictInt]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> HistoryResourcePagingResource:
        """get_history


        :param page:
        :type page: int
        :param page_size:
        :type page_size: int
        :param sort_key:
        :type sort_key: str
        :param sort_direction:
        :type sort_direction: SortDirection
        :param event_type:
        :type event_type: List[int]
        :param successful:
        :type successful: bool
        :param download_id:
        :type download_id: str
        :param indexer_ids:
        :type indexer_ids: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_history_serialize(
            page=page,
            page_size=page_size,
            sort_key=sort_key,
            sort_direction=sort_direction,
            event_type=event_type,
            successful=successful,
            download_id=download_id,
            indexer_ids=indexer_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "HistoryResourcePagingResource",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_history_with_http_info(
        self,
        page: Optional[StrictInt] = None,
        page_size: Optional[StrictInt] = None,
        sort_key: Optional[StrictStr] = None,
        sort_direction: Optional[SortDirection] = None,
        event_type: Optional[List[StrictInt]] = None,
        successful: Optional[StrictBool] = None,
        download_id: Optional[StrictStr] = None,
        indexer_ids: Optional[List[StrictInt]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[HistoryResourcePagingResource]:
        """get_history


        :param page:
        :type page: int
        :param page_size:
        :type page_size: int
        :param sort_key:
        :type sort_key: str
        :param sort_direction:
        :type sort_direction: SortDirection
        :param event_type:
        :type event_type: List[int]
        :param successful:
        :type successful: bool
        :param download_id:
        :type download_id: str
        :param indexer_ids:
        :type indexer_ids: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_history_serialize(
            page=page,
            page_size=page_size,
            sort_key=sort_key,
            sort_direction=sort_direction,
            event_type=event_type,
            successful=successful,
            download_id=download_id,
            indexer_ids=indexer_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "HistoryResourcePagingResource",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_history_without_preload_content(
        self,
        page: Optional[StrictInt] = None,
        page_size: Optional[StrictInt] = None,
        sort_key: Optional[StrictStr] = None,
        sort_direction: Optional[SortDirection] = None,
        event_type: Optional[List[StrictInt]] = None,
        successful: Optional[StrictBool] = None,
        download_id: Optional[StrictStr] = None,
        indexer_ids: Optional[List[StrictInt]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_history


        :param page:
        :type page: int
        :param page_size:
        :type page_size: int
        :param sort_key:
        :type sort_key: str
        :param sort_direction:
        :type sort_direction: SortDirection
        :param event_type:
        :type event_type: List[int]
        :param successful:
        :type successful: bool
        :param download_id:
        :type download_id: str
        :param indexer_ids:
        :type indexer_ids: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_history_serialize(
            page=page,
            page_size=page_size,
            sort_key=sort_key,
            sort_direction=sort_direction,
            event_type=event_type,
            successful=successful,
            download_id=download_id,
            indexer_ids=indexer_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "HistoryResourcePagingResource",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_history_serialize(
        self,
        page,
        page_size,
        sort_key,
        sort_direction,
        event_type,
        successful,
        download_id,
        indexer_ids,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'eventType': 'multi',
            'indexerIds': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if sort_key is not None:
            
            _query_params.append(('sortKey', sort_key))
            
        if sort_direction is not None:
            
            _query_params.append(('sortDirection', sort_direction.value))
            
        if event_type is not None:
            
            _query_params.append(('eventType', event_type))
            
        if successful is not None:
            
            _query_params.append(('successful', successful))
            
        if download_id is not None:
            
            _query_params.append(('downloadId', download_id))
            
        if indexer_ids is not None:
            
            _query_params.append(('indexerIds', indexer_ids))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey', 
            'X-Api-Key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/history',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_history_indexer(
        self,
        indexer_id: Optional[StrictInt] = None,
        event_type: Optional[HistoryEventType] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[HistoryResource]:
        """list_history_indexer


        :param indexer_id:
        :type indexer_id: int
        :param event_type:
        :type event_type: HistoryEventType
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_history_indexer_serialize(
            indexer_id=indexer_id,
            event_type=event_type,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "List[HistoryResource]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_history_indexer_with_http_info(
        self,
        indexer_id: Optional[StrictInt] = None,
        event_type: Optional[HistoryEventType] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[HistoryResource]]:
        """list_history_indexer


        :param indexer_id:
        :type indexer_id: int
        :param event_type:
        :type event_type: HistoryEventType
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_history_indexer_serialize(
            indexer_id=indexer_id,
            event_type=event_type,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "List[HistoryResource]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_history_indexer_without_preload_content(
        self,
        indexer_id: Optional[StrictInt] = None,
        event_type: Optional[HistoryEventType] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """list_history_indexer


        :param indexer_id:
        :type indexer_id: int
        :param event_type:
        :type event_type: HistoryEventType
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_history_indexer_serialize(
            indexer_id=indexer_id,
            event_type=event_type,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "List[HistoryResource]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_history_indexer_serialize(
        self,
        indexer_id,
        event_type,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if indexer_id is not None:
            
            _query_params.append(('indexerId', indexer_id))
            
        if event_type is not None:
            
            _query_params.append(('eventType', event_type.value))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey', 
            'X-Api-Key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/history/indexer',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_history_since(
        self,
        var_date: Optional[datetime] = None,
        event_type: Optional[HistoryEventType] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[HistoryResource]:
        """list_history_since


        :param var_date:
        :type var_date: datetime
        :param event_type:
        :type event_type: HistoryEventType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_history_since_serialize(
            var_date=var_date,
            event_type=event_type,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "List[HistoryResource]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_history_since_with_http_info(
        self,
        var_date: Optional[datetime] = None,
        event_type: Optional[HistoryEventType] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[HistoryResource]]:
        """list_history_since


        :param var_date:
        :type var_date: datetime
        :param event_type:
        :type event_type: HistoryEventType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_history_since_serialize(
            var_date=var_date,
            event_type=event_type,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "List[HistoryResource]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_history_since_without_preload_content(
        self,
        var_date: Optional[datetime] = None,
        event_type: Optional[HistoryEventType] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """list_history_since


        :param var_date:
        :type var_date: datetime
        :param event_type:
        :type event_type: HistoryEventType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_history_since_serialize(
            var_date=var_date,
            event_type=event_type,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': "List[HistoryResource]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_history_since_serialize(
        self,
        var_date,
        event_type,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if var_date is not None:
            if isinstance(var_date, datetime):
                _query_params.append(
                    (
                        'date',
                        var_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('date', var_date))
            
        if event_type is not None:
            
            _query_params.append(('eventType', event_type.value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey', 
            'X-Api-Key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/history/since',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


